aboutsummaryrefslogtreecommitdiff
path: root/example.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'example.cpp')
-rw-r--r--example.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/example.cpp b/example.cpp
index 6cceeb6..0bea84a 100644
--- a/example.cpp
+++ b/example.cpp
@@ -78,11 +78,11 @@ void TheBestClass::do_everything() {
* @category some_bug
*
* @description
* Some weared bug lol
* what is this???
*/
-void some_weard_fun() {
+void some_weird_function() {
}
@@ -78,11 +78,11 @@ void TheBestClass::do_everything() {
*
* @description
- * Some weared bug lol
+ * Some weird bug lol
* what is this???
*/